@@ -28,6 +28,9 @@ def main():
     vcf_in = VariantFile(args.vcf)
     vcf_out = VariantFile('-', 'w', header=vcf_in.header)
     for rec in vcf_in.fetch():
+        if args.remove_bnd:
+            if rec.info['SVTYPE'] == 'BND':
+                continue
         groups = {s.split('_')[0] for s in rec.samples
                   if not any(a is None for a in rec.samples[s].allele_indices)
                   if sum(rec.samples[s].allele_indices) > 0}
